@@ -5,9 +5,14 @@ import subprocess
 
 from itertools import takewhile
 
+try:
+    from staticfiles import finders
+except ImportError:
+    from django.contrib.staticfiles import finders # noqa
+
 from pipeline.conf import settings
-from pipeline.storage import storage
-from pipeline.utils import filepath_to_uri, to_class, relpath
+from pipeline.utils import to_class, relpath
+from pipeline.storage import default_storage
 
 MAX_IMAGE_SIZE = 32700
 
@@ -15,9 +20,8 @@ EMBEDDABLE = r'[/]?embed/'
 URL_DETECTOR = r'url\([\'"]?([^\s)]+\.[a-z]+[\?\#\d\w]*)[\'"]?\)'
 URL_REPLACER = r'url\(__EMBED__(.+?)(\?\d+)?\)'
 
-MHTML_START = "/*\r\nContent-Type: multipart/related; boundary=\"MHTML_MARK\"\r\n\r\n"
-MHTML_SEPARATOR = "--MHTML_MARK\r\n"
-MHTML_END = "\r\n--MHTML_MARK--\r\n*/\r\n"
+DEFAULT_TEMPLATE_FUNC = "template"
+TEMPLATE_FUNC = """var template = function(str){var fn = new Function('obj', 'var __p=[],print=function(){__p.push.apply(__p,arguments);};with(obj||{}){__p.push(\''+str.replace(/\\/g, '\\\\').replace(/'/g, "\\'").replace(/<%=([\s\S]+?)%>/g,function(match,code){return "',"+code.replace(/\\'/g, "'")+",'";}).replace(/<%([\s\S]+?)%>/g,function(match,code){return "');"+code.replace(/\\'/g, "'").replace(/[\r\n\t]/g,' ')+"__p.push('";}).replace(/\r/g,'\\r').replace(/\n/g,'\\n').replace(/\t/g,'\\t')+"');}return __p.join('');");return fn;};"""
 
 MIME_TYPES = {
     '.png': 'image/png',
@@ -37,7 +41,8 @@ FONT_EXTS = ['.ttf', '.otf', '.woff']
 class Compressor(object):
     asset_contents = {}
 
-    def __init__(self, verbose=False):
+    def __init__(self, storage=default_storage, verbose=False):
+        self.storage = storage
         self.verbose = verbose
 
     def js_compressor(self):
@@ -48,7 +53,7 @@ class Compressor(object):
         return to_class(settings.PIPELINE_CSS_COMPRESSOR)
     css_compressor = property(css_compressor)
 
-    def compress_js(self, paths, templates=None, asset_url=None, **kwargs):
+    def compress_js(self, paths, templates=None, **kwargs):
         """Concatenate and compress JS files"""
         js = self.concatenate(paths)
         if templates:
@@ -61,11 +66,9 @@ class Compressor(object):
 
         return js
 
-    def compress_css(self, paths, variant=None, asset_url=None,
-                     absolute_asset_paths=True, **kwargs):
+    def compress_css(self, paths, output_filename, variant=None, **kwargs):
         """Concatenate and compress CSS files"""
-        css = self.concatenate_and_rewrite(paths, variant,
-                                           absolute_asset_paths)
+        css = self.concatenate_and_rewrite(paths, output_filename, variant)
         compressor = self.css_compressor
         if compressor:
             css = getattr(compressor(verbose=self.verbose), 'compress_css')(css)
@@ -73,8 +76,6 @@ class Compressor(object):
             return css
         elif variant == "datauri":
             return self.with_data_uri(css)
-        elif variant == "mhtml":
-            return self.with_mhtml(css, asset_url)
         else:
             raise CompressorError("\"%s\" is not a valid variant" % variant)
 
@@ -95,8 +96,10 @@ class Compressor(object):
                 settings.PIPELINE_TEMPLATE_FUNC,
                 contents
             )
+        compiler = TEMPLATE_FUNC if settings.PIPELINE_TEMPLATE_FUNC == DEFAULT_TEMPLATE_FUNC else ""
         return "\n".join([
             "%(namespace)s = %(namespace)s || {};" % {'namespace': namespace},
+            compiler,
             compiled
         ])
 
@@ -117,7 +120,7 @@ class Compressor(object):
         ), r"\1", path)
         return re.sub(r"[\/\\]", "_", name)
 
-    def concatenate_and_rewrite(self, paths, variant=None, absolute_asset_paths=True):
+    def concatenate_and_rewrite(self, paths, output_filename, variant=None):
         """Concatenate together files and rewrite urls"""
         stylesheets = []
         for path in paths:
@@ -126,7 +129,7 @@ class Compressor(object):
                 if asset_path.startswith("http") or asset_path.startswith("//"):
                     return "url(%s)" % asset_path
                 asset_url = self.construct_asset_path(asset_path, path,
-                    variant, absolute_asset_paths)
+                    output_filename, variant)
                 return "url(%s)" % asset_url
             content = self.read_file(path)
             content = re.sub(URL_DETECTOR, reconstruct, content)
@@ -137,17 +140,14 @@ class Compressor(object):
         """Concatenate together a list of files"""
         return '\n'.join([self.read_file(path) for path in paths])
 
-    def construct_asset_path(self, asset_path, css_path, variant=None, absolute_asset_paths=True):
+    def construct_asset_path(self, asset_path, css_path, output_filename, variant=None):
         """Return a rewritten asset URL for a stylesheet"""
         public_path = self.absolute_path(asset_path, os.path.dirname(css_path))
         if self.embeddable(public_path, variant):
             return "__EMBED__%s" % public_path
-        if not absolute_asset_paths:
-            return asset_path
         if not os.path.isabs(asset_path):
-            asset_path = self.relative_path(public_path)
-        asset_url = filepath_to_uri(asset_path)
-        return settings.PIPELINE_URL + asset_url[1:]
+            asset_path = self.relative_path(public_path, output_filename)
+        return asset_path
 
     def embeddable(self, path, variant):
         """Is the asset embeddable ?"""
@@ -155,7 +155,7 @@ class Compressor(object):
         font = ext in FONT_EXTS
         if not variant:
             return False
-        if not (re.search(EMBEDDABLE, path) and storage.exists(path)):
+        if not (re.search(EMBEDDABLE, path) and self.storage.exists(path)):
             return False
         if not ext in EMBED_EXTS:
             return False
@@ -171,29 +171,6 @@ class Compressor(object):
             return "url(\"data:%s;charset=utf-8;base64,%s\")" % (mime_type, data)
         return re.sub(URL_REPLACER, datauri, css)
 
-    def with_mhtml(self, css, asset_url):
-        paths = {}
-        def mhtml(match):
-            path = match.group(1)
-            if not path in paths:
-                paths[path] = "%s-%s" % (match.start(), os.path.basename(path))
-            return "url(mhtml:%s!%s)" % (asset_url, paths[path])
-        css = re.sub(URL_REPLACER, mhtml, css)
-        mhtml = []
-        for path, location in paths.items():
-            mime_type = self.mime_type(path)
-            data = self.encoded_content(path)
-            mhtml.extend([
-                MHTML_SEPARATOR,
-                "Content-Location: %s\r\n" % location,
-                "Content-Type: %s\r\n" % mime_type,
-                "Content-Transfer-Encoding: base64\r\n\r\n",
-                data,
-                "\r\n"
-            ])
-        output = [MHTML_START, mhtml, MHTML_END, css]
-        return ''.join([part for parts in output for part in parts])
-
     def encoded_content(self, path):
         """Return the base64 encoded contents"""
         if path in self.__class__.asset_contents:
@@ -213,19 +190,20 @@ class Compressor(object):
         given the path of the stylesheet that contains it.
         """
         if os.path.isabs(path):
-            path = os.path.join(settings.PIPELINE_ROOT, path)
+            path = os.path.join(default_storage.location, path)
         else:
             path = os.path.join(start, path)
         return os.path.normpath(path)
 
-    def relative_path(self, absolute_path):
+    def relative_path(self, absolute_path, output_filename):
         """Rewrite paths relative to the output stylesheet path"""
-        absolute_path = self.absolute_path(absolute_path, settings.PIPELINE_ROOT)
-        return os.path.join(os.sep, relpath(absolute_path, settings.PIPELINE_ROOT))
+        absolute_path = os.path.join(settings.PIPELINE_ROOT, absolute_path)
+        output_path = os.path.join(settings.PIPELINE_ROOT, os.path.dirname(output_filename))
+        return relpath(absolute_path, output_path)
 
     def read_file(self, path):
         """Read file content in binary mode"""
-        file = storage.open(path, 'rb')
+        file = default_storage.open(path, 'rb')
         content = file.read()
         file.close()
         return content
